@@ -2,8 +2,8 @@
 
   Copyright 1997-1998 by Leonard N. Zubkoff <lnz@dandelion.com>
 
-$Date: 2002/02/05 16:51:11 $
-$Revision: 1.8.2.3 $
+$Date: 2002/09/27 17:23:28 $
+$Revision: 1.8.2.7 $
 
   This file created Feb 2000 by Eric Lee Green <eric@badtux.org> from pieces
   extracted from mtx.c, plus some additional routines. 
@@ -438,10 +438,15 @@ static ElementStatus_T *AllocateElementData(ElementModeSense_T *mode_sense) {
 void copy_barcode(unsigned char *src, unsigned char *dest) {
   int i;
   
-  for (i=0; i < 37; i++) {
-    *dest++ = *src++;
+  for (i=0; i < 36; i++) {
+    *dest=*src++;
+#ifdef __WEIRD_CHAR_SUPPRESS
+    if ((*dest < 32) || (*dest > 127))
+       *dest = '\0';
+#endif
+     dest++;
   }
-  *dest=0; /* null-terminate, sigh. */ 
+  dest=0; /* null-terminate, sigh. */ 
 }
 
 
@@ -1216,8 +1221,20 @@ void PrintRequestSense(RequestSense_T *RequestSense)
 
 #endif
 
-/* $Date: 2002/02/05 16:51:11 $
+/* $Date: 2002/09/27 17:23:28 $
  * $Log: mtxl.c,v $
+ * Revision 1.8.2.7  2002/09/27 17:23:28  elgreen
+ * Don't dereference pointer in barcode stuff
+ *
+ * Revision 1.8.2.6  2002/09/27 17:20:18  elgreen
+ * doh, get rid of the + from the patch process!
+ *
+ * Revision 1.8.2.5  2002/09/27 17:17:13  elgreen
+ * fix copy_barcode
+ *
+ * Revision 1.8.2.4  2002/09/27 16:49:43  elgreen
+ * copy_barcode was off by one (sigh!)
+ *
  * Revision 1.8.2.3  2002/02/05 16:51:11  elgreen
  * mtx 1.2.16pre3
  *
